#
# spec file for package fping
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fping
Version:        4.0
Release:        lp150.2.3
Summary:        A program to ping multiple hosts
License:        MIT
Group:          Productivity/Networking/Diagnostic
Url:            http://www.fping.org
Source:         http://fping.org/dist/%{name}-%{version}.tar.gz
Requires(pre):  permissions
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FPing is a ping-like program that uses the Internet Control Message
Protocol (ICMP) echo request to determine if a target host is
responding. FPing differs from ping in that you can specify any number
of targets on the command line or specify a file containing a list of
targets to ping. Instead of sending pings to one target until it times
out or replies, FPing sends a ping packet and moves on to the next
target in a round-robin fashion.

In the default mode, if a target replies, it is noted and removed from
the list of targets to check. If a target does not respond within a
certain time limit or retry limit, it is designated as unreachable.
FPing also supports sending a specified number of pings to a target or
looping indefinitely (as in ping).

Unlike ping, FPing is meant to be used in scripts. Its output is
designed to be easy to parse.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%post
%set_permissions %{_sbindir}/fping

%verifyscript
%verify_permissions -e %{_sbindir}/fping

%files
%defattr(-,root,root)
%doc CHANGELOG.md INSTALL
%{_mandir}/man8/fping.8%{ext_man}
%verify(not mode caps) %attr(0755,root,root) %{_sbindir}/fping

%changelog
* Wed Dec 13 2017 astieger@suse.com
- fping now has cap_net_raw, fix build in Factory (bsc#1047921)
* Wed Jun 21 2017 tchvatal@suse.com
- Cleanup a bit with spec-cleaner basically just to use new make_install
  macro
* Thu May 11 2017 jengelh@inai.de
- Do away with %%__ macro indirections.
* Mon May  8 2017 liedke@rz.uni-mannheim.de
- Update to version 4.0
  * feature: Auto-adjust timeout for -c/-C/-l mode to value of -p
  * feature: Enforce -t timeout on reply packets, by discarding late
    packets (#32)
  * feature: Option -d/--rdns now always does a rdns-lookup, even for
    names, as '-n' was doing until now
  * feature: Keep original name if a hostname is given with -n/--name
  * feature: New option -6 to force IPv6
  * feature: New option -4 to force IPv4
  * feature: IPv6 enabled by default
  * feature: Long option names for all options
  * feature: Unified 'fping' and 'fping6' into one binary (#80)
  * feature: fping and fping6 are now unified into one binary.
  * bugfix: -i/-p restrictions disabled by default
    (enable with --enable-safe-limits)
  * bugfix: Default interval -i changed from 25ms to 10ms
  * bugfix: Fix compatibility issue with GNU Hurd
  * bugfix: A C99 compiler is now required
  * bugfix: Option parsing with optparse
  * bugfix: New changelog file format
* Tue Feb 28 2017 liedke@rz.uni-mannheim.de
- Update to version 3.16:
  * (feature) Support kernel-timestamping of received packets (#46)
  * (feature) Simplify restrictions: only -i >= 1 and -p >= 10 are
    enforced now
  * (bugfix) Fix option -m to return all IPs of a hostname
  * (bugfix) Fix option -H (ttl) for IPv6
  * (bugfix) Fix option -M (don't fragment) for IPv6
  * (bugfix) Fix option -O (ToS) for IPv6
  * (bugfix) Fix compatibility issue with AIX (#69, @blentzgh)
  * (bugfix) Fix option -q not suppressing some ICMP error messages (#83)
  * (bugfix) Fix option -M expecting an argument, when it shouldn't
  * (bugfix) Fix minor issues found by Coverity Scan
- Update to version 3.15:
  * (bugfix) Fix compiler errors on platforms other than Linux (related
    to the new -M option, #109)
  * Test suite fixes for macOS
- Update to version 3.14:
  * (feature) Ignore network and broadcast for cidrs /31 and /32
    (#102, Martin Topholm)
  * (feature) New option '-M' to set the "Don't Fragment" flag
    (#91, Don Bowman)
  * (feature) New option '-N' to output statistics for netdata
    (see: http://my-netdata.io/, #105, Costa Tsaousis)
  * (feature) New option '-o' to calculate total outage time (#90, @jgerbeck)
  * (bugfix) Exit code should be 2 when the hostname can't be resolved
    (fixes #98, reported by @green-fox)
  * (bugfix)  Fix issue compliling on RHEL/Centos 7 (#95, @jbackman)
  * (bugfix) Lower -i limit to 1 instead of 10
  * (bugfix) Improve interval preciseness of -Q reporting
  * (bugfix) Fix occasional false positive in -Q reporting (#97)
  * (bugfix) Solaris 10 portability fix (#107, Peter Bray)
* Wed Oct 21 2015 zaitor@opensuse.org
- Update to version 3.13:
  + Bugfix: Fix ICMP errors sometimes causing crashes with
    fping >= 3.11.
* Thu Oct 15 2015 zaitor@opensuse.org
- Update to version 3.12:
  + Bugfix: Fix fping6 -R (#84).
- Changes from version 3.11:
  + Feature:
  - New option -R to use random bytes instead of NULLs (#72).
  - Small documentation and performance improvements.
  + Bugfix: Fix double entries with fping -u and unreachable hosts.
  + Internal: Use sockaddr_storage and simplify code, so that we
    can one day support both IPv4 and IPv6 with the same binary.
* Sun May  4 2014 zaitor@opensuse.org
- Update to version 3.10:
  + Fix confusing error message with -g and IPv6 addresses (#58).
  + Allow option '-f' also for non-root (since setuid privileges
    are dropped).
  + Do not retry twice DNS lookup on DNS lookup problem.
  + Remove support for NIS groups.
  + Better document -B backoff-factor and when it can be used (#33)
  + More tests added.
* Sat Mar  8 2014 zaitor@opensuse.org
- Update to version 3.9:
  + Fix random output on socket error (#56).
  + Support ppc64le architecture by including alpha libtool
    version.
  + Fix compilation problem on FreeBSD (#57).
  + Initial test suite and continous intergration (with
    travis-ci.org / coveralls.io).
  + Don't output usage information on error.
- Changes from version 3.8:
  + Fix segmentation fault introduced in version 3.7 with loop mode
    (#55).
- Changes from version 3.7:
  + Allow running as non-root on Mac OS X by using non-privileged
    ICMP (#7).
  + Remove unnecessary IPv6 socket options.
  + Fix again compatibility issue with FreeBSD.
  + Fix fping hanging forever on permanent sendto failure.
  + Fix duplicate echo reply packets causing early stop in count
    mode (#53).
- Changes from version 3.6:
  + Fix loop issue after 65536 pings (#12).
  + Minimum ping data size is now 0.
  + Removed setsockopt IPV6_CHECKSUM, which shouldn't be set and
    breaks compiling on Solaris.
  + Fix wrong min RTT value with -Q option (#51).
- Drop export CFLAGS="%%optflags -D_GNU_SOURCE -fwhole-program", it
  breaks the build.
* Sun Aug 18 2013 zaitor@opensuse.org
- Update to version 3.5:
  * Fix sprint_tm buffer size crash.
  * Addded -D flag to print timestamps.
  * Fix fping6 build on OS X 10.8.
  * Fix compatibility issue with FreeBSD (#39).
  * Fping.spec: fix setuid permissions and provides fping6.
  * Re-create configure script with autoconf 2.69 for aarch64
    support (#45).
* Thu Jan 31 2013 crrodriguez@opensuse.org
- Enable missing ipv6 support
- tweak out CFLAGS.
* Tue Oct 16 2012 puzel@suse.com
- update to 3.4
  * Revert "Output statistics to stdout instead of stderr", because
    it breaks tools assuming the output goes to stderr
* Mon Aug 20 2012 pascal.bleser@opensuse.org
- update to 3.3:
  * Do not output icmp errors with -q (#1)
  * Add --enable-ipv4 and --enable-ipv6 options to configure
  * Fix removing of unreachable hosts when doing loop (#13 #23)
  * Fix -A for fping6 (#14)
  * Fix "options inet6" breaking IPv4 name resolution (#17)
  * Output statistics to stdout instead of stderr (#9)
  * Set default data size to 56 bytes on all architectures (#18)
  * Convert man-page source to POD for easier maintenance
  * Fix error message on DNS error for IPv6 hosts (#27)
  * Fix -n flag in fping6 (#28)
* Fri Jun  8 2012 wojtek@suse.cz
-Update to 3.2
  * Improve documentation for -g option (G.W. Haywood)
  * Performance optimization for big select timeouts (#10, Andrey
  * Bondarenko)
  * Fix restart of select call after interrupt signal (#8, Boian
  * Bonev)
  * Fix infinite loop caused by linked list corruption (#11,
  * Boian Bonev)
* Sun May 20 2012 zaitor@opensuse.org
- Update to version 3.1:
  + -g option (generate): exclude network and broadcast address
    for cidr ranges.
  + do not explicitely check if running as root, to make it
    possible to install fping with linux capabilities instead of
    making it setuid (setcap cap_net_raw+ep fping).
  + ANSI C (C89) compiler now a requirement.
  + Portability fixes.
  + Reorganized source directory.
  + Bugfix: fix timeout issue on Solaris.
  + Man-page fixes.
  + Added -H option to specify number of hops.
  + Output usage information to stdout when called with -h
* Wed Feb  8 2012 puzel@suse.com
- update to fping-3.0
  * rewritten main loop for improved performance
  * -T parameter (select timeout) now obsolete
  * Maintenance taken over from unresponsive previous maintainer
  * New homepage: www.fping.org
- drop fping-2.4b2-fixwarnings.patch (obsolete)
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Wed Nov 18 2009 puzel@novell.com
- add ipv6 support (bnc#555691)
* Fri Feb  8 2008 lrupp@suse.de
- convert the Changelog to Unix
- add COPYING, remove INSTALL from docudir
- use macros
- build parallel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri May  7 2004 hmacht@suse.de
- Upgrade to version 2.4b2
* Thu Apr 22 2004 postadal@suse.cz
- fixed gcc warnings
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Jun 11 2001 schwab@suse.de
- Fix alignment problem properly.
* Wed Jul 19 2000 schwab@suse.de
- Fix alignment problem.
- Pass CFLAGS during configure run.
* Thu Apr 13 2000 nadvornik@suse.cz
- added BuildRoot
* Sat Feb 12 2000 grimmer@suse.de
- added Group tag to spec file
- use version macro in spec file
- added full URL to Source tag
- use _mandir macro in spec file
- added CXXFLAGS to %%build section
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Apr 22 1999 ro@suse.de
- fixed for alpha
* Fri Jan 29 1999 grimmer@suse.de
- new Package (Version 2.2b1)
